@@ -1,5 +1,5 @@
 from sila2.client.client_feature import ClientFeature
-from sila2.client.client_metadata import ClientMetadata
+from sila2.client.client_metadata import ClientMetadata, ClientMetadataInstance
 from sila2.client.client_observable_command import ClientObservableCommand
 from sila2.client.client_observable_command_instance import ClientObservableCommandInstance
 from sila2.client.client_observable_property import ClientObservableProperty
@@ -11,6 +11,7 @@ from sila2.client.sila_client import SilaClient
 __all__ = [
     "ClientFeature",
     "ClientMetadata",
+    "ClientMetadataInstance",
     "ClientObservableCommand",
     "ClientObservableCommandInstance",
     "ClientObservableProperty",
