@@ -1,7 +1,8 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Generic, TypeVar
+from typing import TYPE_CHECKING, Generic, Iterable, Optional, TypeVar
 
+from sila2.client.client_metadata import ClientMetadataInstance
 from sila2.client.utils import call_rpc_function
 from sila2.framework.command.unobservable_command import UnobservableCommand
 
@@ -20,7 +21,7 @@ class ClientUnobservableCommand(Generic[T]):
         self._wrapped_command = wrapped_command
 
     def __call__(self, *args, **kwargs) -> T:
-        raw_metadata = kwargs.pop("metadata", None)
+        raw_metadata: Optional[Iterable[ClientMetadataInstance]] = kwargs.pop("metadata", None)
         param_msg = self._wrapped_command.parameters.to_message(
             *args, **kwargs, toplevel_named_data_node=self._wrapped_command.parameters
         )
