@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import logging
 import uuid
 from concurrent.futures import ThreadPoolExecutor
 from typing import TYPE_CHECKING, Dict, List, Optional, Union
@@ -15,6 +16,7 @@ from sila2.framework.constraints.pattern import Pattern
 from sila2.framework.feature import Feature
 from sila2.framework.fully_qualified_identifier import FullyQualifiedIdentifier
 from sila2.framework.utils import parse_feature_definition, xpath_sila
+from sila2.server.encryption import generate_self_signed_certificate
 from sila2.server.feature_implementation_base import FeatureImplementationBase
 from sila2.server.feature_implementation_servicer import FeatureImplementationServicer
 from sila2.server.metadata_interceptor import MetadataInterceptor
@@ -28,6 +30,7 @@ class SilaServer:
     features: Dict[str, Feature]
     feature_servicers: Dict[str, FeatureImplementationServicer]
     running: bool
+    generated_ca: Optional[bytes]
 
     server_name: str
     server_type: str
@@ -57,6 +60,8 @@ class SilaServer:
         max_child_task_workers: int = 100,
     ):
         self.running = False
+        self.logger = logging.getLogger(__name__)
+        self.generated_ca = None
 
         # import locally to prevent circular import
         from sila2.features.silaservice import SiLAServiceFeature
@@ -154,18 +159,72 @@ class SilaServer:
     def add_metadata_interceptor(self, interceptor: MetadataInterceptor):
         self.metadata_interceptors.append(interceptor)
 
-    def start_insecure(self, address: str, port: int, enable_discovery: bool = True):
+    def __start(
+        self,
+        address: str,
+        port: int,
+        *,
+        insecure: bool,
+        private_key: Optional[bytes] = None,
+        cert_chain: Optional[bytes] = None,
+        enable_discovery: bool = True,
+    ):
+        # start implementations
         for servicer in self.feature_servicers.values():
             servicer.implementation.start()
 
-        self.grpc_server.add_insecure_port(f"{address}:{port}")
+        # start grpc server
+        address_string = f"{address}:{port}"
+        self.generated_ca = None
+        if insecure:
+            self.logger.warning("Starting SiLA server without encryption. This violates the SiLA 2 specification.")
+            self.grpc_server.add_insecure_port(address_string)
+        else:
+            if private_key is None and cert_chain is None:
+                if not enable_discovery:
+                    raise ValueError("If discovery is disabled, private key and certificate chain are required")
+
+                self.logger.info("Generating self-signed certificate")
+                private_key, cert_chain = generate_self_signed_certificate(self.server_uuid, address)
+                self.generated_ca = cert_chain
+            if private_key is None or cert_chain is None:
+                raise ValueError(
+                    "For secure connections, either provide both the private key and certificate chain, "
+                    "or none of them (server will then generate a self-signed certificate)"
+                )
+            self.logger.info("Starting SiLA server with encryption")
+            credentials = grpc.ssl_server_credentials([(private_key, cert_chain)])
+            self.grpc_server.add_secure_port(address_string, server_credentials=credentials)
         self.grpc_server.start()
 
+        # start zeroconf broadcasting
         if enable_discovery:
-            info = self.service_broadcaster.register_server(self, address, port)
+            self.logger.info("Starting zeroconf broadcasting for SiLA Server Discovery")
+            info = self.service_broadcaster.register_server(self, address, port, ca=self.generated_ca)
             self.running_instances.append(info)
+
         self.running = True
 
+    def start_insecure(self, address: str, port: int, enable_discovery: bool = True):
+        self.__start(address, port, insecure=True, enable_discovery=enable_discovery)
+
+    def start(
+        self,
+        address: str,
+        port: int,
+        private_key: bytes = None,
+        cert_chain: bytes = None,
+        enable_discovery: bool = True,
+    ):
+        self.__start(
+            address,
+            port,
+            insecure=False,
+            private_key=private_key,
+            cert_chain=cert_chain,
+            enable_discovery=enable_discovery,
+        )
+
     def stop(self, grace_period: Optional[float] = None):
         # stop zeroconf broadcasting
         for info in self.running_instances:
